.First.lib <- function(lib, pkg) {
try(require("sound")) 
cat("Welcome to seewave!\nThe package is regularly updated, check for new version\nPlease see citation('seewave') if you use 'seewave' in publications\n")
}
